@@ -3,8 +3,7 @@ from dataclasses import dataclass
 from typing import Union
 
 from canonicaljson import encode_canonical_json
-
-from metaphor.common.metadata_change_event import (
+from metaphor.models.metadata_change_event import (
     DashboardLogicalID,
     DatasetLogicalID,
     EntityType,
