@@ -11,8 +11,9 @@ except ImportError:
     print("Please install metaphor[looker] extra\n")
     raise
 
+from metaphor.models.metadata_change_event import DataPlatform, DatasetLogicalID
+
 from metaphor.common.entity_id import EntityId, EntityType
-from metaphor.common.metadata_change_event import DataPlatform, DatasetLogicalID
 
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
